@@ -1,18 +1,24 @@
 import json
+import sys
 import os
 
 
 class ProfileHandler:
     def __init__(self):
+        
+        def resource_path(relative_path):
+            """ Get absolute path to resource, works for dev and for PyInstaller """
+            if hasattr(sys, '_MEIPASS'):
+                return os.path.join(sys._MEIPASS, "TopasGraphSim", relative_path)
 
-        self.profile_path = str(
-            os.path.join(
-                os.path.dirname(os.path.realpath(__file__)),
-                "..",
+            return os.path.join(os.path.dirname(os.path.abspath(__file__)), os.pardir, os.pardir, os.pardir, relative_path)
+
+        self.profile_path = resource_path(os.path.join(
+                "topasgraphsim",
+                "src",
                 "resources",
-                "profile.json",
-            )
-        )
+                "profile.json"))
+        
         self.profile = self.read_data()
 
     def read_data(self):
