@@ -9,7 +9,7 @@ from .profile import ProfileHandler
 class CheckForUpdates:
     def __init__(self):
 
-        currentVersion = "23.1.2"
+        currentVersion = "24.0.0"
         try:
             newestVersion = requests.get(
                 "https://api.github.com/repos/sebasj13/topasgraphsim/releases/latest"
@@ -29,6 +29,6 @@ class CheckForUpdates:
 
             if dialog == True:
                 try:
-                    webbrowser.open("https://pypi.org/project/topasgraphsim/")
+                    webbrowser.open("https://github.com/sebasj13/TopasGraphSim")
                 except Exception:
                     return
